@@ -1,14 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ghub" "5.0.4"
+(define-package "ghub" "20251006.1821"
   "Client libraries for Git forge APIs."
-  '((emacs    "29.1")
-    (compat   "30.1")
-    (cond-let "0.2")
-    (llama    "1.0")
-    (treepy   "0.1.2"))
+  '((emacs  "29.1")
+    (compat "30.1")
+    (llama  "1.0")
+    (treepy "0.1.2"))
   :url "https://github.com/magit/ghub"
-  :commit "c22858596c1f5a1f5b439e475e7ba0e6a2e1718b"
-  :revdesc "v5.0.4-0-gc22858596c1f"
+  :commit "6dc4ff700fc515157131b2106a17bb667579d449"
+  :revdesc "6dc4ff700fc5"
   :keywords '("tools")
   :authors '(("Jonas Bernoulli" . "emacs.ghub@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.ghub@jonas.bernoulli.dev")))
